@@ -1,7 +1,5 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use std::convert::TryFrom;
-
 use glib::translate::*;
 
 use crate::{prelude::*, Entry};
@@ -17,7 +15,8 @@ pub trait EntryExtManual: sealed::Sealed + IsA<Entry> + 'static {
     #[doc(alias = "gtk_entry_get_invisible_char")]
     #[doc(alias = "get_invisible_char")]
     fn invisible_char(&self) -> Option<char> {
-        let ret = unsafe { ffi::gtk_entry_get_invisible_char(self.as_ref().to_glib_none().0) };
+        let ret =
+            unsafe { crate::ffi::gtk_entry_get_invisible_char(self.as_ref().to_glib_none().0) };
         if ret == 0 {
             return None;
         }
