@@ -1,19 +1,22 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::Scale;
 use glib::translate::*;
-use glib::IsA;
 
-pub trait ScaleExtManual: 'static {
-    #[doc(alias = "gtk_scale_set_format_value_func")]
-    #[doc(alias = "set_format_value_func")]
-    fn unset_format_value_func(&self);
+use crate::{prelude::*, Scale};
+
+mod sealed {
+    pub trait Sealed {}
+    impl<T: super::IsA<super::Scale>> Sealed for T {}
 }
 
-impl<O: IsA<Scale>> ScaleExtManual for O {
+// rustdoc-stripper-ignore-next
+/// Trait containing manually implemented methods of [`Scale`](crate::Scale).
+pub trait ScaleExtManual: sealed::Sealed + IsA<Scale> + 'static {
+    #[doc(alias = "gtk_scale_set_format_value_func")]
+    #[doc(alias = "set_format_value_func")]
     fn unset_format_value_func(&self) {
         unsafe {
-            ffi::gtk_scale_set_format_value_func(
+            crate::ffi::gtk_scale_set_format_value_func(
                 self.as_ref().to_glib_none().0,
                 None,
                 std::ptr::null_mut(),
@@ -22,3 +25,5 @@ impl<O: IsA<Scale>> ScaleExtManual for O {
         }
     }
 }
+
+impl<O: IsA<Scale>> ScaleExtManual for O {}
